@@ -44,7 +44,7 @@ class Logger:
     ---------------------
     POWERTOOLS_SERVICE_NAME : str
         service name
-    LOG_LEVEL: str, int
+    LOG_LEVEL: str
         logging level (e.g. INFO, DEBUG)
     POWERTOOLS_LOGGER_SAMPLE_RATE: float
         samping rate ranging from 0 to 1, 1 being 100% sampling
@@ -53,7 +53,7 @@ class Logger:
     ----------
     service : str, optional
         service name to be appended in logs, by default "service_undefined"
-    level : str, optional
+    level : str, int optional
         logging.level, by default "INFO"
     child: bool, optional
         create a child Logger named <service>.<caller_file_name>, False by default
@@ -132,8 +132,11 @@ class Logger:
         # https://github.com/awslabs/aws-lambda-powertools-python/issues/97
         return getattr(self._logger, name)
 
-    def _get_log_level(self, level: str):
+    def _get_log_level(self, level: Union[str, int]) -> Union[str, int]:
         """ Returns preferred log level set by the customer in upper case """
+        if isinstance(level, int):
+            return level
+
         log_level: str = level or os.getenv("LOG_LEVEL")
         log_level = log_level.upper() if log_level is not None else logging.INFO
 
